@@ -131,9 +131,8 @@ class Account(Entity):
         """:obj:`list` of :obj:`Device`: Fetch a list of all devices in the account.
 
         Args:
-            device_id (str): Device ID.
             attributes (list): Optional list of device attributes to return.
-            attributes (zones): Optional list of zones to filter.
+            zones (list): Optional list of zones to filter.
             include_subzones (bool): Flag to indicate if should include subzone devices in result.
                 This will only work when `zones` are passed.
             params (dict): Optional query parameters.
@@ -148,8 +147,8 @@ class Account(Entity):
             params["attributes"] = json.dumps(attributes)
         if zones is not None:
             params["zones"] = json.dumps(zones)
-        if include_subzones is not None:
-            params["include_subzones"] = json.dumps(include_subzones)
+            if include_subzones is not None:
+                params["include_subzones"] = json.dumps(include_subzones)
 
         result = self.api.call("GET", "/accounts/{}/devices".format(self._id), params=params, **api_call_kwargs)
         if not isinstance(result, list):
