@@ -86,7 +86,16 @@ class Alert(object):
         return to_unix_time(utc_time)
 
 
-def get_alert(api, account_id, alert_id, attributes=None, params=None, api_call_kwargs={}, **kwargs):
+def get_alert(
+        api,
+        account_id,
+        alert_id,
+        attributes=None,
+        params=None,
+        raw=False,
+        api_call_kwargs={},
+        **kwargs
+):
     """:obj:`Alert` : Fetch an Alert by its ID (ALTXXXXXXXXXXXX).
 
     Args:
@@ -95,6 +104,7 @@ def get_alert(api, account_id, alert_id, attributes=None, params=None, api_call_
         alert_id (str): Alert ID.
         attributes (list): Optional list of alert attributes to return.
         params (dict): Optional query parameters.
+        raw (bool): Will return the raw JSON if True. False by default.
         api_call_kwargs (dict): Optional keyword arguments for api call.
         **kwargs: Extra keyword arguments passed to Alert object.
     """
@@ -108,11 +118,24 @@ def get_alert(api, account_id, alert_id, attributes=None, params=None, api_call_
     alert_data = api.call("GET", path, params=params, **api_call_kwargs)
     if not alert_data:
         return None
-    alert = Alert(alert_data["id"], alert_data, **kwargs)
+    if raw:
+        alert = alert_data
+    else:
+        alert = Alert(alert_data["id"], alert_data, **kwargs)
     return alert
 
 
-def get_alerts(api, account_id, device_id=None, zone_id=None, attributes=None, params=None, api_call_kwargs={}, **kwargs):
+def get_alerts(
+        api,
+        account_id,
+        device_id=None,
+        zone_id=None,
+        attributes=None,
+        params=None,
+        raw=False,
+        api_call_kwargs={},
+        **kwargs
+):
     """:obj:`list` : Fetch a list of alerts for an account, device or zone.
 
     Args:
@@ -122,6 +145,7 @@ def get_alerts(api, account_id, device_id=None, zone_id=None, attributes=None, p
         zone_id (str): Optional zone ID.
         attributes (list): Optional list of alert attributes to return.
         params (dict): Optional query parameters.
+        raw (bool): Will return the raw JSON if True. False by default.
         api_call_kwargs (dict): Optional keyword arguments for api call.
         **kwargs: Extra keyword arguments passed to Alert object.
     """
@@ -141,5 +165,8 @@ def get_alerts(api, account_id, device_id=None, zone_id=None, attributes=None, p
     alerts_data = api.call("GET", path, params=params, **api_call_kwargs)
     if not alerts_data:
         return []
-    alerts = [Alert(alert_data["id"], alert_data, **kwargs) for alert_data in alerts_data]
+    if raw:
+        alerts = alerts_data
+    else:
+        alerts = [Alert(alert_data["id"], alert_data, **kwargs) for alert_data in alerts_data]
     return alerts
