@@ -90,7 +90,7 @@ class APIHandler(object):
         self.profiler_min_duration = profiler_min_duration
         self.global_timeout = global_timeout
 
-    def get_session(self, retry_total=None, retry_backoff_factor=None):
+    def get_session(self, retry_total=60, retry_backoff_factor=None):
         session = requests.Session()
         if retry_total is None:
             retry_total = self.retry_config.get('total')
@@ -100,7 +100,7 @@ class APIHandler(object):
             retry = Retry(
                 total=retry_total or 1,
                 backoff_factor=retry_backoff_factor or 1,
-                status_forcelist=self.retry_config.get('status_forcelist', (500, 502, 504))
+                status_forcelist=self.retry_config.get('status_forcelist', (502, 504))
             )
             adapter = HTTPAdapter(
                 max_retries=retry,
@@ -151,7 +151,7 @@ class APIHandler(object):
             no_auth=False,
             raw=False,
             timeout=None,
-            retry_total=None,
+            retry_total=60,
             retry_backoff_factor=None,
             ):
         """Performs the API request handling authorization and the status codes errors.
