@@ -43,10 +43,11 @@ def setup(**kwargs):
     with error_message_catch('New token creation'):
         token = client.get_token(token_id)
         description = f"Freedom CLI token created for user {user}"
+        # TODO change this for policies
         result = client.create_token(
-            token.allowed_actions,
-            token.accounts,
-            token.devices,
+            token._data.get('allowed_actions'),
+            token._data.get('accounts'),
+            token._data.get('devices'),
             description,
             create_secret=True,
             raw=True,
