@@ -74,6 +74,10 @@ class Device(Entity):
             return response
         else:
             return None
+        
+    def delete(self):
+        """dict: deletes this device from the FR API."""
+        return self.api.call("DELETE", f"/accounts/{self.account}/devices/{self._id}")
 
     @property
     def account(self):
