@@ -19,18 +19,6 @@ class Token(Entity):
         else:
             return '/accounts/{}/tokens'.format(self.account_id)
 
-    @property
-    def allowed_actions(self):
-        return self._data['allowed_actions']
-
-    @property
-    def accounts(self):
-        return self._data['accounts']
-
-    @property
-    def devices(self):
-        return self._data['devices']
-
     @property
     def expiration_utc_secs(self):
         return self._data.get('expiration_utc_secs')
