@@ -27,12 +27,8 @@ class User(Entity):
         return self._data.get("first_name")
 
     @property
-    def role(self):
-        return self._data.get("role")
-
-    @property
-    def accounts(self, **kwargs):
-        return [
-            Account(account_id, None, api=self.api, **kwargs)
-            for account_id in self._data["accounts"]
-        ]
+    def main_account(self, **kwargs):
+        main_account_id = self._data.get("main_account_id")
+        if not main_account_id:
+            return None
+        return Account(main_account_id, None, api=self.api, **kwargs)
